//
//  AuthNViewController.m
//  AuthN
//
//  Created by CA Technologies
//  Copyright (c) 2012 CA Technologies. All rights reserved.
//

#import "ProjectGlobals.h"
#import "AuthNViewController.h"
#import "BizPageViewController.h"
#import "AuthNService.h"

@interface AuthNViewController ()
- (void)alert:(NSString *)message;
@end

@implementation AuthNViewController
@synthesize _userid;
@synthesize _pw;
@synthesize _status;
@synthesize _loginButton;
@synthesize _logoutButton;

- (void)alert:(NSString *)message {
    UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"AuthN Service"
                                                    message:message
                                                   delegate:self
                                          cancelButtonTitle:@"OK"
                                          otherButtonTitles:nil, nil];        
    [alert show];
}

// Methods to resign First Responder and get rid of Keyboard
UITextField *currentTextField;

- (void)textFieldDidBeginEditing:(UITextField *)textField {
    currentTextField = textField;
}

- (BOOL)textFieldShouldReturn:(UITextField *)textField {
    [currentTextField resignFirstResponder];
    return YES;
}

// *** BUTTON CLICK METHODS ***

- (IBAction)loginPressed {
    ProjectGlobals *myGlobals = [ProjectGlobals sharedInstance];
    
    AuthNService *authNService = [[AuthNService alloc] init];
    AuthNContext *authNContext = authNService.authNContext;
    
    void(^successBlock)(void) = ^(void) {
        [self status:authNContext.description];
        NSRange range = [authNContext.urlStr.description rangeOfString:@"success.html"];
        if ((authNContext.statusCode == 200) && (range.location != NSNotFound)) {
            [self alert: @"You HAVE been successfully logged in." ];
            if (myGlobals.gBizPage) {
                UIStoryboard *storyBoard = [UIStoryboard storyboardWithName:@"MainStoryboard_iPhone" bundle:nil];
                UIViewController *uivc = [storyBoard instantiateViewControllerWithIdentifier:@"BizPageViewController"];          
                [self presentModalViewController:uivc animated:YES]; 
            }
        }
        else {
            [self alert: @"You have NOT been successfully logged in." ];
        }
    };
    
    void(^failureBlock)(void) = ^(void) {
        [self status:authNContext.description];
        [self alert: authNContext.body ];   
    };

    [authNContext setUid:[_userid text]];
    [authNContext setPw:[_pw text]];
    [authNContext setAuthType: AUTHN_AUTH_QUERY];
    [authNContext setProcessCookies:YES];
    [authNContext setUrlStr:[myGlobals.gServer stringByAppendingString:myGlobals.gLogin]];
    [authNContext setSuccessBlock:successBlock];
    [authNContext setFailureBlock:failureBlock];
    [authNService execute];
}

- (IBAction)logoutPressed {
    ProjectGlobals *myGlobals = [ProjectGlobals sharedInstance];
    
    AuthNService *authNService = [[AuthNService alloc] init];
    AuthNContext *authNContext = authNService.authNContext;
    
    void(^successBlock)(void) = ^(void) {
        [self status:authNContext.description];
        NSRange range = [authNContext.urlStr.description rangeOfString:@"success.html"];
        if ((authNContext.statusCode == 200) && (range.location != NSNotFound)) {
            [self alert: @"You HAVE been successfully logged out." ];
        }
        else {
            [self alert: @"You have NOT been successfully logged out." ];
        }
    };
    
    void(^failureBlock)(void) = ^(void) {
        [self status:authNContext.description];
        [self alert: authNContext.body ];
    };

    [authNContext setAuthType: AUTHN_AUTH_QUERY];
    [authNContext setProcessCookies:YES];
    [authNContext setUrlStr:[myGlobals.gServer stringByAppendingString:myGlobals.gLogout]];
    [authNContext setSuccessBlock:successBlock];
    [authNContext setFailureBlock:failureBlock];
    [authNService execute];
}

- (IBAction)isSessionPressed:(id)sender {
    // get a reference to the project globals (aka UserDefaults)
    ProjectGlobals *myGlobals = [ProjectGlobals sharedInstance];
    // instantiate an authNService
    AuthNService *authNService = [[AuthNService alloc] init];
    // ask the authNService for its authNContext
    AuthNContext *authNContext = authNService.authNContext;
    
    // define a block that will execute if the HTTP request is processed without a CATASTROPHIC failure
    void(^successBlock)(void) = ^(void) {
        [self status:authNContext.description];
        NSRange range = [authNContext.body rangeOfString:@"Not Authenticated"];
        if ((authNContext.statusCode != 200) || (range.location != NSNotFound)) {
            [self alert: @"Session does NOT exist." ];
        }
        else {
            [self alert: @"Session DOES exist." ];
        }
    };
    
    // define a block that will execute if the HTTP request is processed WITH a CATASTROPHIC failure
    void(^failureBlock)(void) = ^(void) {
        [self status:authNContext.description];
        [self alert: authNContext.body ];
    };
    
    // The userid/password (if present) will be sent through as query parameters
    [authNContext setAuthType: AUTHN_AUTH_QUERY];
    // we need to capture the cookies for subsequent requests to the server
    [authNContext setProcessCookies:YES];
    // set the session URL to be the server + session user variables
    [authNContext setUrlStr:[myGlobals.gServer stringByAppendingString:myGlobals.gSession]];
    // set the successBlock
    [authNContext setSuccessBlock:successBlock];
    // set the failureBlock
    [authNContext setFailureBlock:failureBlock];
    [authNService execute];
}

// *** UTILITY METHODS ***

- (IBAction)clrPressed {
    [[self _status] setText:@""];
}

- (void)status:(id)newStatusText {
    [[self _status] setText:[[[self _status] text] stringByAppendingString:newStatusText]];
    [[self _status] scrollRangeToVisible: [[[self _status]text]rangeOfString:newStatusText]];
}

- (void)viewDidUnload {
    [self set_status:nil];
    [self set_loginButton:nil];
    [self set_logoutButton:nil];
    [super viewDidUnload];
}

- (void)viewDidLoadX {
    [self clrPressed];
    [super viewDidLoad];
}

@end
