//
//  AppScreenViewController.m
//  AuthN
//
//  Created by CA Technologies
//  Copyright (c) 2012 CA Technologies. All rights reserved.
//

#import "BizPageViewController.h"

@interface BizPageViewController ()
- (void)alert:(NSString *)message;
- (void)updateSessionCheckTime;
@end

@implementation BizPageViewController

@synthesize webPage;
@synthesize logoutButton;
@synthesize sessionExistButton;

- (void)alert:(NSString *)message {
    UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"AuthN Service"
                                                    message:message
                                                   delegate:self
                                          cancelButtonTitle:@"OK"
                                          otherButtonTitles:nil, nil];        
    [alert show];
}

- (void)updateSessionCheckTime {
    NSDate *today = [NSDate date];
    NSDateFormatter *dateFormat = [[NSDateFormatter alloc] init];
    [dateFormat setDateFormat:@"h:mm:ss a, zzz"];
    NSString *dateString = [dateFormat stringFromDate:today];
    NSString *title = [@"Session Check Time: " stringByAppendingString:dateString];
    [[self sessionExistButton] setTitle: title forState: UIControlStateNormal];
}

- (IBAction)sessionExistPressed {
    ProjectGlobals *myGlobals = [ProjectGlobals sharedInstance];
    AuthNService *authNService = [[AuthNService alloc] init];
    AuthNContext *authNContext = authNService.authNContext;
    void(^successBlock)(void) = ^(void) {
        NSString *body = authNContext.body;
        NSRange range = [body rangeOfString:@"Not Authenticated"];
        if ((authNContext.statusCode != 200) || (range.location != NSNotFound)) {
            [self alert: @"Session does NOT exist." ];
            UIStoryboard *storyBoard = [UIStoryboard storyboardWithName:@"MainStoryboard_iPhone" bundle:nil];
            UIViewController *asvc = [storyBoard instantiateViewControllerWithIdentifier:@"UINavigationController"];     
            [self presentModalViewController:asvc animated:YES]; 
        }
        else {
            [self alert: @"Session DOES exist." ];     
            [self updateSessionCheckTime];
        }
    };
    void(^failureBlock)(void) = ^(void) {
        [self alert: authNContext.body ];     
    };
    
    [authNContext setUrlStr:[myGlobals.gServer stringByAppendingString:myGlobals.gSession]];
    [authNContext setProcessCookies:YES];
    [authNContext setAuthType: AUTHN_AUTH_QUERY];
    [authNContext setSuccessBlock:successBlock];
    [authNContext setFailureBlock:failureBlock];
    [authNService execute];
}

- (IBAction)logoutPressed {
    ProjectGlobals *myGlobals = [ProjectGlobals sharedInstance];
    AuthNService *authNService = [[AuthNService alloc] init];
    AuthNContext *authNContext = authNService.authNContext;
    void(^successBlock)(void) = ^(void) {    
        NSRange range = [authNContext.urlStr.description rangeOfString:@"success.html"];
        if ((authNContext.statusCode == 200) && (range.location != NSNotFound)) {
            [self alert: @"You HAVE been successfully logged out." ];
            UIStoryboard *storyBoard = [UIStoryboard storyboardWithName:@"MainStoryboard_iPhone" bundle:nil];
            UIViewController *asvc = [storyBoard instantiateViewControllerWithIdentifier:@"UINavigationController"];     
            [self presentModalViewController:asvc animated:YES]; 
        }
        else {
            [self alert: @"You have NOT been successfully logged out." ];
        }
    };
    void(^failureBlock)(void) = ^(void) {
        [self alert: authNContext.body ];  
    };
    
    [authNContext setUrlStr:[myGlobals.gServer stringByAppendingString:myGlobals.gLogout]];
    [authNContext setProcessCookies:YES];
    [authNContext setAuthType: AUTHN_AUTH_QUERY];
    [authNContext setSuccessBlock:successBlock];
    [authNContext setFailureBlock:failureBlock];
    [authNService execute];
}

- (void)viewDidLoad {
    ProjectGlobals *myGlobals = [ProjectGlobals sharedInstance];
    NSString *gTarget = [myGlobals gTarget];
    NSMutableString *mutableString = [NSMutableString stringWithString:gTarget];
    
    // remove authn OR authns from the qTrget
    NSRange range = [mutableString rangeOfString:@"authn:"];
    if (range.location != NSNotFound) {
        [mutableString deleteCharactersInRange:range];
    }   
    
    // create the embedded browser
    NSURL *url = [NSURL URLWithString:mutableString];
    NSURLRequest *request = [NSURLRequest requestWithURL:url];
    self.webPage.scalesPageToFit = YES;
    [[self webPage] loadRequest:request];
    NSString *title = [@"Logout from: " stringByAppendingString:mutableString];
    [[self logoutButton] setTitle: title forState: UIControlStateNormal];
    [self updateSessionCheckTime];
}

@end
