//
//  ConfViewController.m
//  AuthN
//
//  Created by CA Technologies
//  Copyright (c) 2012 CA Technologies. All rights reserved.
//

#import "ConfViewController.h"
#import "ProjectGlobals.h"

@interface ConfViewController ()
@end

@implementation ConfViewController

@synthesize configClearButton;
@synthesize configSaveButton;
@synthesize showBizPageButton;
@synthesize targetInputField;
@synthesize loginIDInputField;
@synthesize serverInputField;
@synthesize loginInputField;
@synthesize logoffInputField;
@synthesize sessionInputField;

UITextField *currentTextField;

// Following is used to ensure the keyboard disappears when RETURN is pressed
- (void)textFieldDidBeginEditing:(UITextField *)textField {
    currentTextField = textField;
}

- (BOOL)textFieldShouldReturn:(UITextField *)textField {
    [currentTextField resignFirstResponder];
    return YES;
}

// Here's the code for the Save and Clear buttons
- (IBAction)configClearButton:(id)sender {
    [loginIDInputField setText:@" "];
    [loginInputField setText:@" "];    
    [logoffInputField setText:@" "];
    [serverInputField setText:@" "];
    [sessionInputField setText:@" "];
    [targetInputField setText:@" "];    
    [showBizPageButton setOn: YES];
}

- (IBAction)resetButton:(id)sender {   
    // OK - this method is just in case the user hits CLEAR then SAVE and ends up with a blank
    // set of input fields. This will read the Config.plist file in the bundle and copy it back to the 
    // Config.plist in the Documents folder
    ProjectGlobals *myGlobals = [ProjectGlobals sharedInstance];
  
    // Grab a reference to the bundle Config.plist and read into a dictionary object
    NSString *configFileFromBundle = [[NSBundle mainBundle] pathForResource:@"Config" ofType:@"plist"];
    NSDictionary *configFileContents = [[NSDictionary alloc] initWithContentsOfFile:configFileFromBundle];

    // Now read the stored config data into the globals
    myGlobals.gLoginID = [configFileContents objectForKey:@"gLoginID"];
    myGlobals.gLogin = [configFileContents objectForKey:@"gLogin"];
    myGlobals.gLogout = [configFileContents objectForKey:@"gLogout"];
    myGlobals.gServer = [configFileContents objectForKey:@"gServer"];
    myGlobals.gSession = [configFileContents objectForKey:@"gSession"];
    if ([configFileContents objectForKey:@"gBizKey"] != nil) {
        myGlobals.gBizPage = [[configFileContents objectForKey:@"gBizKey"] boolValue];
    }
    myGlobals.gTarget = [configFileContents objectForKey:@"gTarget"];

    // Now display in the ViewController
    [loginIDInputField setText:myGlobals.gLoginID];
    [loginInputField setText:myGlobals.gLogin];
    [logoffInputField setText:myGlobals.gLogout];
    [serverInputField setText:myGlobals.gServer];
    [sessionInputField setText:myGlobals.gSession];
    [showBizPageButton setOn:YES];
    [targetInputField setText:myGlobals.gTarget]; 
    
    // Force a SAVE button action by invoking it's method
    [self configSaveButton:sender];
}

- (IBAction)configSaveButton:(id)sender {
    ProjectGlobals *myGlobals = [ProjectGlobals sharedInstance];
    // Update the global vars in case the user made changes
    myGlobals.gLoginID = loginIDInputField.text;    
    myGlobals.gLogin = loginInputField.text;
    myGlobals.gLogout = logoffInputField.text;
    myGlobals.gServer = serverInputField.text;
    myGlobals.gSession = sessionInputField.text;
    myGlobals.gBizPage = showBizPageButton.on;
    myGlobals.gTarget = targetInputField.text;    
}

- (void)viewDidLoad {
    [super viewDidLoad];
	// Do any additional setup after loading the view.
    ProjectGlobals *projectGlobals = [ProjectGlobals sharedInstance];
    
    //change keyboard RETURN button to DONE button
    loginIDInputField.returnKeyType = UIReturnKeyDone;
    loginInputField.returnKeyType = UIReturnKeyDone;
    logoffInputField.returnKeyType = UIReturnKeyDone;
    sessionInputField.returnKeyType = UIReturnKeyDone;
    serverInputField.returnKeyType = UIReturnKeyDone;
    targetInputField.returnKeyType = UIReturnKeyDone;

    // The following needs to be set so that the keyboard release works
    loginIDInputField.delegate = self;
    loginInputField.delegate = self;
    logoffInputField.delegate = self;
    sessionInputField.delegate = self;
    serverInputField.delegate = self;
    targetInputField.delegate = self;    
    
    // Now display in the ViewController
    [loginIDInputField setText:projectGlobals.gLoginID];
    [loginInputField setText:projectGlobals.gLogin];    
    [logoffInputField setText:projectGlobals.gLogout];
    [serverInputField setText:projectGlobals.gServer];
    [sessionInputField setText:projectGlobals.gSession];
    [showBizPageButton setOn:projectGlobals.gBizPage];
    [targetInputField setText:projectGlobals.gTarget];
}

- (void)viewDidUnload {
    [self setServerInputField:nil];
    [self setLoginInputField:nil];
    [self setLogoffInputField:nil];
    [self setSessionInputField:nil];
    [self setConfigClearButton:nil];
    [self setLoginIDInputField:nil];
    [self setShowBizPageButton:nil];
    [self setTargetInputField:nil];
    [super viewDidUnload];
    // Release any retained subviews of the main view.
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

@end
