package com.example.smandroidauthn;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.List;

import org.apache.http.Header;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.StatusLine;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.cookie.Cookie;
import org.apache.http.entity.BufferedHttpEntity;
import org.apache.http.impl.client.DefaultHttpClient;

import android.content.SharedPreferences;
import android.util.Log;
import android.webkit.CookieManager;

public class AuthComm {
	
	/* 	
	 	To support Android 2.3 devices you will need to implement your own certificate checking
	  
	  	Please note that the class below is acceptable for testing purposes only and should
	  	not be for production environments. 
	
		public class InsecureSSLSocketFactory extends SSLSocketFactory {
			SSLContext sslContext = SSLContext.getInstance("TLS");
			
			public InSecureSSLSocketFactory(KeyStore truststore)
					throws NoSuchAlgorithmException, KeyManagementException,
					KeyStoreException, UnrecoverableKeyException {
		
				super(truststore);
				TrustManager tm = new X509TrustManager() {
					
					@Override
					public X509Certificate[] getAcceptedIssuers() {
						return null;
					}
					
					@Override
					public void checkServerTrusted(X509Certificate[] chain, String authType)
							throws CertificateException {		
					}
					
					@Override
					public void checkClientTrusted(X509Certificate[] chain, String authType)
							throws CertificateException {			
					}
				};
				sslContext.init(null, new TrustManager[]{ tm},null);
			}
	
			@Override
			public Socket createSocket() throws IOException {
				return sslContext.getSocketFactory().createSocket();
				
			}
	
			@Override
			public Socket createSocket(Socket socket, String host, int port,
					boolean autoClose) throws IOException, UnknownHostException {
				return sslContext.getSocketFactory().createSocket(socket, host, port, autoClose);
			}
		}
	
	*/
	
	SharedPreferences preferences;
	private String targetURL;
    private String serverURL;
    private String loginPath;
    private String logoutPath;
    private String sessionPath;
    DefaultHttpClient httpclient;
   
	
	public AuthComm(SharedPreferences preferences){
		this.preferences = preferences;
		loadConfig();
		
		try {
			
			/* 
			  Android 2.3 and below use this support code here. Android 2.3 required manual certificate checks for HTTPS.
			  
			  By default the code below is insecure and should not be utilized in a production environment.
			  
			  
			HttpParams params = new BasicHttpParams();
		    HttpProtocolParams.setVersion(params, HttpVersion.HTTP_1_1);
		    HttpProtocolParams.setContentCharset(params, HTTP.UTF_8);

			KeyStore trustStore = KeyStore.getInstance(KeyStore.getDefaultType());
			
			//Demo only, do not do this, replace with your real keystore (Android 2.3 and below)
			trustStore.load(null,null);
			
			SSLSocketFactory sslFactory = new InsecureSSLSocketFactory(trustStore);
			sslFactory.setHostnameVerifier(SSLSocketFactory.ALLOW_ALL_HOSTNAME_VERIFIER);
			
			SchemeRegistry registry = new SchemeRegistry();
			registry.register(new Scheme("http",PlainSocketFactory.getSocketFactory(),80));
			registry.register(new Scheme("https",sslFactory,443));
			
			ClientConnectionManager ccm = new ThreadSafeClientConnManager(params, registry);
			httpclient = new DefaultHttpClient(ccm,params);
			*/
			
			httpclient = new DefaultHttpClient();
			
		} catch (Exception e) {
			e.printStackTrace();
		}
		
		
	}
	
	public void onDestory(){
		httpclient.getConnectionManager().shutdown();
	}
	
	public void loadConfig(){
		/*
		 * Load configuration options from our preferences
		 */
		targetURL = (preferences.getString(ConfView.TARGET_URL,""));
		serverURL = (preferences.getString(ConfView.SERVER_URL,""));
		loginPath = (preferences.getString(ConfView.LOGIN_PATH,""));
		logoutPath = (preferences.getString(ConfView.LOGOUT_PATH,""));
		sessionPath = (preferences.getString(ConfView.SESSION_PATH,""));
	}
	
	public boolean logout() throws Exception {
		loadConfig();
		
		//Build our logout URI
		String uriDomain = serverURL.substring(serverURL.indexOf("http://") + "http://".length(), serverURL.lastIndexOf("/"));
		String url = serverURL + logoutPath;
		
		Log.d("smandroidauthn", "URL for logout:" + url);
		
		//Create the logout request
		HttpGet logoutReq = new HttpGet(url);
		
		//Add our cookies for this domain to the logout request
		String cookieString = CookieManager.getInstance().getCookie(uriDomain);  
		Log.d("smandroidauthn","Cookie String:" + cookieString);
		logoutReq.setHeader("Cookie", cookieString);
		
		//Submit the request
		HttpResponse resp = httpclient.execute(logoutReq);
		
		//Get our list of headers
		Header[] headers = resp.getAllHeaders();
		for(Header h : headers){
			Log.d("smandroidauthn", "Got header from logout:" +h.toString());
		}
		
		//Capture the output for the log
		HttpEntity ht = resp.getEntity();
		BufferedHttpEntity buf = new BufferedHttpEntity(ht);
        InputStream is = buf.getContent();
        BufferedReader r = new BufferedReader(new InputStreamReader(is));

        StringBuilder total = new StringBuilder();
        String line;
        while ((line = r.readLine()) != null) {
            total.append(line);
        }
        StatusLine s1 = resp.getStatusLine();
        Log.d("smandroidauthn", "Logout resp:" + total.toString()); 
		Log.d("smandroidauthn", "Logout status:" + s1.toString());
		if(total.toString().equals("fail")){
			return false;
		}
		return true;
	}
	
	
	public boolean login(String mUserID, String mPassword, StringBuffer result) throws Exception {
		loadConfig();
		
		//Construct the login URL
		String url = serverURL + loginPath;
		url = url + "?password=" + mPassword + "&user=" + mUserID;
		
		Log.d("smandroidauthn", "URL:" + url);
		
		
		//Create and execute the login request
		HttpGet authReq = new HttpGet(url);
		HttpResponse resp = httpclient.execute(authReq);
		
		//Print out the headers
		Header[] headers = resp.getAllHeaders();
		for(Header h : headers){
			Log.d("smandroidauthn", "Got header from resp:" +h.toString());
		}
		
		//Capture the output
		HttpEntity ht = resp.getEntity();
		BufferedHttpEntity buf = new BufferedHttpEntity(ht);
        InputStream is = buf.getContent();
        BufferedReader r = new BufferedReader(new InputStreamReader(is));

        StringBuilder total = new StringBuilder();
        String line;
        while ((line = r.readLine()) != null) {
            total.append(line);
        }
        StatusLine s1 = resp.getStatusLine();
        Log.d("smandroidauthn", "Got resp:" + total.toString()); 
		
		Log.d("smandroidauthn", "Got status:" + s1.toString());
		result.append(total.toString());
		
		//Save the cookies
		List<Cookie> cookies = httpclient.getCookieStore().getCookies();
	    if(cookies != null)
	    {
            for(Cookie cookie : cookies)
            {
                String cookieString = cookie.getName() + "=" + cookie.getValue() + "; domain=" + cookie.getDomain();
                Log.d("smandroidauthn", "saving cookie:" + cookieString);
                CookieManager.getInstance().setCookie(cookie.getDomain(), cookieString);  
            }
        }
	
	    //Did we get an HTTP 200 code? If so success if not failure!
		if(s1.getStatusCode() != 200){
			return false;
		}
		if(total.toString().equals("fail")){
			return false;
		}
		
		return isAuthenticated();
	
	}
	
	public boolean isAuthenticated() throws Exception {
		loadConfig();
		
		//Construct our status URL
		String uriDomain = serverURL.substring(serverURL.indexOf("http://") + "http://".length(), serverURL.lastIndexOf("/"));
		Log.d("smandriodauthn", "URIDom:" + uriDomain);
		
		//Get our cookies
		String cookieString = CookieManager.getInstance().getCookie(uriDomain);  
		Log.d("smandriodauthn", "Cooking setting:" + cookieString);
		String url = serverURL + sessionPath;
		
		//Send off the status request
		HttpGet statusGet = new HttpGet(url);
		statusGet.setHeader("Cookie", cookieString);
		
		HttpResponse resp = httpclient.execute(statusGet);
		
		//Capture the output
		HttpEntity ht = resp.getEntity();
		BufferedHttpEntity buf = new BufferedHttpEntity(ht);
        InputStream is = buf.getContent();
        BufferedReader r = new BufferedReader(new InputStreamReader(is));

        StringBuilder total = new StringBuilder();
        String line;
        
        while ((line = r.readLine()) != null) {
            total.append(line);
        }
      
        //Look to see if the output contained 'Not Authed...' or 'Authed...'
        Log.d("smandroidauthn", "Return:"+total.toString());
        if(total.indexOf("Not Authenticated") >= 0){
			return false;
		}else if(total.indexOf("Authenticated") >= 0){
			return true;
		}
        return false;  
	}
	
}
